import os

from django.apps import AppConfig
from django.conf import settings

from vue_helper.exceptions import VueAppNotFound
from vue_helper.utils import set_production_assets_paths


class VueHelperConfig(AppConfig):
    name = 'vue_helper'

    def ready(self):
        if settings.VUE_DEV_MODE is True:
            return

        try:
            vue_dist_path = os.path.join(
                os.path.dirname(self.apps.app_configs[settings.VUE_APP_NAME].path),
                settings.VUE_APP_NAME,
                'static',
                settings.VUE_APP_DIST_DIR_NAME
            )
        except KeyError:
            raise VueAppNotFound(f"Couldn't find {settings.VUE_APP_NAME}, make sure it's added to INSTALLED_APPS")

        set_production_assets_paths(vue_dist_path=vue_dist_path)



import os
import re

from django.conf import settings
from django.templatetags.static import static

from vue_helper.dist import vue_dist_css, vue_dist_js
from vue_helper.exceptions import VueDistIndexFileNotFound


def set_production_assets_paths(vue_dist_path):
    vue_dist_assets = get_production_assets(vue_dist_path)
    vue_dist_css.update(vue_dist_assets['css'])
    vue_dist_js.update(vue_dist_assets['js'])


def get_production_assets(vue_dist_path):
    try:
        with open(os.path.join(vue_dist_path, 'index.html'), 'r') as index_file:
            return parse_html_for_js_and_css_links(index_file.read())
    except FileNotFoundError as err:
        raise VueDistIndexFileNotFound(err)


def parse_html_for_js_and_css_links(html):
    parsed_js_src = set([alias_path(match.group(1)) for match in
                         re.finditer('<script src=[\"]?(\S+.js)', html, re.MULTILINE | re.IGNORECASE)])
    parsed_css_links = set([alias_path(match.group(1)) for match in
                            re.finditer('<link href=[\"]?(\S+.css)', html, re.MULTILINE | re.IGNORECASE)])
    return {
        'js': parsed_js_src,
        'css': parsed_css_links
    }


def alias_path(path):
    return static(os.path.join(*settings.VUE_APP_DIST_DIR_NAME.split('/'), *path.split('/')))



from django import template
from django.conf import settings

from vue_helper.dist import vue_dist_js, vue_dist_css

register = template.Library()


@register.inclusion_tag('vue_helper/vue_scripts.html')
def vue_scripts():
    return {
        'VUE_DEV_MODE': settings.VUE_DEV_MODE,
        'VUE_DEV_SERVER_URL': settings.VUE_DEV_SERVER_URL,
        'VUE_DIST_JS': vue_dist_js
    }


@register.inclusion_tag('vue_helper/vue_preload_scripts.html')
def vue_preload_scripts():
    return {
        'VUE_DEV_MODE': settings.VUE_DEV_MODE,
        'VUE_DIST_JS': vue_dist_js
    }


@register.inclusion_tag('vue_helper/vue_styles.html')
def vue_styles():
    return {
        'VUE_DEV_MODE': settings.VUE_DEV_MODE,
        'VUE_DEV_SERVER_URL': settings.VUE_DEV_SERVER_URL,
        'VUE_DIST_CSS': vue_dist_css
    }


@register.inclusion_tag('vue_helper/vue_preload_styles.html')
def vue_preload_styles():
    return {
        'VUE_DEV_MODE': settings.VUE_DEV_MODE,
        'VUE_DIST_CSS': vue_dist_css
    }



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['vue_helper', 'vue_helper.templatetags', 'vue_helper.tests']

package_data = \
{'': ['*'], 'vue_helper': ['templates/vue_helper/*']}

install_requires = \
['django>=2.2,<=3.1']

setup_kwargs = {
    'name': 'django-vue-helper',
    'version': '0.1.0',
    'description': '',
    'long_description': None,
    'author': 'Tim Kamanin',
    'author_email': 'tim@timonweb.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
